X-Git-Url: http://git.vanrenterghem.biz/git.ikiwiki.info.git/blobdiff_plain/b85ca8603aecbd3523201d99edf019db1094b558..093ad8b890543d7fec8283fefeebaf1d23d27a09:/IkiWiki/Plugin/websetup.pm?ds=sidebyside

diff --git a/IkiWiki/Plugin/websetup.pm b/IkiWiki/Plugin/websetup.pm
index 9c032fdc6..d3cbff0d5 100644
--- a/IkiWiki/Plugin/websetup.pm
+++ b/IkiWiki/Plugin/websetup.pm
@@ -151,7 +151,10 @@ sub showfields ($$$@) {
 		my %info=%{shift @show};
 
 		my $description=$info{description};
-		if (exists $info{link} && length $info{link}) {
+		if (exists $info{htmldescription}) {
+			$description=$info{htmldescription};
+		}
+		elsif (exists $info{link} && length $info{link}) {
 			if ($info{link} =~ /^\w+:\/\//) {
 				$description="<a href=\"$info{link}\">$description</a>";
 			}
@@ -288,7 +291,7 @@ sub showform ($$) {
 		fieldsets => [
 			[main => gettext("main")], 
 		],
-		action => $config{cgiurl},
+		action => IkiWiki::cgiurl(),
 		template => {type => 'div'},
 		stylesheet => 1,
 	);
@@ -344,7 +347,7 @@ sub showform ($$) {
 	IkiWiki::decode_form_utf8($form);
 	
 	if ($form->submitted eq "Cancel") {
-		IkiWiki::redirect($cgi, $config{url});
+		IkiWiki::redirect($cgi, IkiWiki::baseurl(undef));
 		return;
 	}
 	elsif (($form->submitted eq 'Save Setup' || $form->submitted eq 'Rebuild Wiki') && $form->validate) {
@@ -447,22 +450,22 @@ sub showform ($$) {
 			IkiWiki::saveindex();
 			IkiWiki::unlockwiki();
 
 			# Print the top part of a standard misctemplate,
 			# then show the rebuild or refresh, live.
 			my $divider="\0";
-			my $html=IkiWiki::misctemplate("setup", $divider);
+			my $html=IkiWiki::cgitemplate($cgi, "setup", $divider);
 			IkiWiki::printheader($session);
 			my ($head, $tail)=split($divider, $html, 2);
 			print $head."<pre>\n";
 
 			my @command;
 			if ($form->submitted eq 'Rebuild Wiki') {
-				@command=("ikiwiki", "-setup", $config{setupfile},
-                                        "-rebuild", "-v");
+				@command=("ikiwiki", "--setup", $config{setupfile},
+                                        "--rebuild", "-v");
 			}
 			else {
-				@command=("ikiwiki", "-setup", $config{setupfile},
-					"-refresh", "-wrappers", "-v");
+				@command=("ikiwiki", "--setup", $config{setupfile},
+					"--refresh", "--wrappers", "-v");
 			}
 
 			close STDERR;
@@ -447,22 +450,22 @@ sub showform ($$) {
 			IkiWiki::unlockwiki();
 
-			# Print the top part of a standard misctemplate,
+			# Print the top part of a standard cgitemplate,
 			# then show the rebuild or refresh, live.
 			my $divider="\0";